# imephu

imephu is a package for generating finder charts for astronomical observations. While primarily intended for the [Southern African Large Telescope](https://www.salt.ac.za), it can be used to create completely custom finder charts.

## Installation

imephu can be installed with pip in the usual way with

```shell
pip install imephu
```

or, avoiding a potential mismatch between python and pip, with

```shell
python -m pip install imephu
```

Python 3.8 or higher is required.

## Usage

A command line interface, `imephu`, allows you to create finder charts from a configuration file. Refer to the [quickstart guide](https://saltastroops.github.io/imephu/quickstart.html) for the details.

Alternatively, you can use an API for creating custom finder charts. An example of how to do this can be found [here](https://saltastroops.github.io/imephu/notebooks/salt.html).

## Documentation

The documentation is hosted at [https://saltastroops.github.io/imephu/](https://saltastroops.github.io/imephu/).


